from distutils.core import setup

setup(
  name = 'tmplt',
  packages = ['tmplt'],
  version = '0.1.0',
  description = 'Minimal templating for Python.',
  author = 'Lim Yuan Qing',
  author_email = 'hello@yuanqing.sg',
  url = 'https://github.com/yuanqing/tmplt.py',
  download_url = 'https://github.com/yuanqing/tmplt/tarball/v0.1.0',
  keywords = ['template', 'templating', 'string', 'interpolate', 'interpolation'],
  classifiers = [
    'Programming Language :: Python',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Topic :: Software Development :: Libraries :: Python Modules'
  ],
)
